@@ -27,15 +27,23 @@
 #include "ui_instrumentpropertiesdialog.h"
 
 InstrumentPropertiesDialog::InstrumentPropertiesDialog(MIDI *midi, QWidget *parent) :
-    QDialog(parent),
+    TutkaDialog(parent),
     midi(midi),
     ui(new Ui::InstrumentPropertiesDialog),
     song(NULL),
     instrument(0)
 {
     ui->setupUi(this);
+    ui->trackerArpeggio->setEditMode(true);
+    ui->trackerArpeggio->setTranslucentWhenNotFocused(true);
 
     connect(ui->comboBoxMidiInterface, SIGNAL(currentIndexChanged(QString)), this, SLOT(setMidiInterface(QString)));
+    connect(ui->horizontalSliderMidiChannel, SIGNAL(valueChanged(int)), this, SLOT(setMidiChannel(int)));
+    connect(ui->checkBoxArpeggio, SIGNAL(toggled(bool)), this, SLOT(toggleArpeggio(bool)));
+    connect(ui->comboBoxArpeggioBaseNote, SIGNAL(currentIndexChanged(int)), this, SLOT(setArpeggioBaseNote(int)));
+    connect(ui->spinBoxArpeggioLength, SIGNAL(valueChanged(int)), this, SLOT(setArpeggioLength(int)));
+    connect(ui->trackerArpeggio, SIGNAL(setLineRequested(int)), ui->trackerArpeggio, SLOT(setLine(int)));
+    connect(ui->trackerArpeggio, SIGNAL(lineEdited()), this, SLOT(advanceTrackerToNextLine()));
     connect(midi, SIGNAL(outputsChanged()), this, SLOT(updateMidiInterfaceComboBox()));
     connect(midi, SIGNAL(outputEnabledChanged(bool)), this, SLOT(updateMidiInterfaceComboBox()));
     updateMidiInterfaceComboBox();
@@ -65,7 +73,6 @@ void InstrumentPropertiesDialog::setInstrument(int number)
         Instrument *oldInstrument = song->instrument(this->instrument);
         disconnect(oldInstrument, SIGNAL(nameChanged(QString)), ui->lineEditName, SLOT(setText(QString)));
         disconnect(ui->lineEditName, SIGNAL(textChanged(QString)), oldInstrument, SLOT(setName(QString)));
-        disconnect(ui->horizontalSliderMidiChannel, SIGNAL(valueChanged(int)), oldInstrument, SLOT(setMidiChannel(int)));
         disconnect(ui->horizontalSliderVolume, SIGNAL(valueChanged(int)), oldInstrument, SLOT(setDefaultVelocity(int)));
         disconnect(ui->horizontalSliderTranspose, SIGNAL(valueChanged(int)), oldInstrument, SLOT(setTranspose(int)));
         disconnect(ui->horizontalSliderHold, SIGNAL(valueChanged(int)), oldInstrument, SLOT(setHold(int)));
@@ -82,12 +89,13 @@ void InstrumentPropertiesDialog::setInstrument(int number)
         ui->horizontalSliderVolume->setValue(instrument->defaultVelocity());
         ui->horizontalSliderTranspose->setValue(instrument->transpose());
         ui->horizontalSliderHold->setValue(instrument->hold());
+        ui->trackerArpeggio->setBlock(instrument->arpeggio());
         updateMidiInterfaceComboBox();
+        updateArpeggio();
 
         // Connect the widgets for editing the instrument
         connect(instrument, SIGNAL(nameChanged(QString)), ui->lineEditName, SLOT(setText(QString)));
         connect(ui->lineEditName, SIGNAL(textChanged(QString)), instrument, SLOT(setName(QString)));
-        connect(ui->horizontalSliderMidiChannel, SIGNAL(valueChanged(int)), this, SLOT(setMidiChannel(int)));
         connect(ui->horizontalSliderVolume, SIGNAL(valueChanged(int)), instrument, SLOT(setDefaultVelocity(int)));
         connect(ui->horizontalSliderTranspose, SIGNAL(valueChanged(int)), instrument, SLOT(setTranspose(int)));
         connect(ui->horizontalSliderHold, SIGNAL(valueChanged(int)), instrument, SLOT(setHold(int)));
@@ -112,6 +120,33 @@ void InstrumentPropertiesDialog::updateMidiInterfaceComboBox()
     ui->comboBoxMidiInterface->blockSignals(false);
 }
 
+void InstrumentPropertiesDialog::updateArpeggio()
+{
+    Block *arpeggio = song->instrument(instrument)->arpeggio();
+    bool enabled = arpeggio != NULL;
+    ui->labelArpeggioBaseNote->setEnabled(enabled);
+    ui->labelArpeggioLength->setEnabled(enabled);
+    ui->labelArpeggioBlock->setEnabled(enabled);
+    ui->comboBoxArpeggioBaseNote->setEnabled(enabled);
+    ui->spinBoxArpeggioLength->setEnabled(enabled);
+    ui->trackerArpeggio->setEnabled(enabled);
+
+    ui->checkBoxArpeggio->blockSignals(true);
+    ui->checkBoxArpeggio->setChecked(enabled);
+    ui->checkBoxArpeggio->blockSignals(false);
+    if (enabled) {
+        ui->spinBoxArpeggioLength->blockSignals(true);
+        ui->spinBoxArpeggioLength->setValue(arpeggio->length());
+        ui->spinBoxArpeggioLength->blockSignals(false);
+        ui->comboBoxArpeggioBaseNote->blockSignals(true);
+        ui->comboBoxArpeggioBaseNote->setCurrentIndex(song->instrument(instrument)->arpeggioBaseNote() - 1);
+        ui->comboBoxArpeggioBaseNote->blockSignals(false);
+    } else {
+        ui->spinBoxArpeggioLength->setValue(8);
+        ui->comboBoxArpeggioBaseNote->setCurrentIndex(48);
+    }
+}
+
 void InstrumentPropertiesDialog::setMidiInterface(const QString &name)
 {
     if (song != NULL) {
@@ -123,3 +158,31 @@ void InstrumentPropertiesDialog::setMidiChannel(int midiChannel)
 {
     song->instrument(instrument)->setMidiChannel(midiChannel - 1);
 }
+
+void InstrumentPropertiesDialog::toggleArpeggio(bool enabled)
+{
+    Block *oldArpeggio = song->instrument(instrument)->arpeggio();
+    song->instrument(instrument)->setArpeggio(enabled ? new Block(1, ui->spinBoxArpeggioLength->value(), 1) : 0);
+    ui->trackerArpeggio->setBlock(song->instrument(instrument)->arpeggio());
+    delete oldArpeggio;
+
+    updateArpeggio();
+}
+
+void InstrumentPropertiesDialog::setArpeggioBaseNote(int baseNote)
+{
+    song->instrument(instrument)->setArpeggioBaseNote(baseNote + 1);
+}
+
+void InstrumentPropertiesDialog::setArpeggioLength(int length)
+{
+    Block *arpeggio = song->instrument(instrument)->arpeggio();
+    if (arpeggio) {
+        arpeggio->setLength(length);
+    }
+}
+
+void InstrumentPropertiesDialog::advanceTrackerToNextLine()
+{
+    ui->trackerArpeggio->setLine(ui->trackerArpeggio->line() + 1);
+}
