@@ -23,7 +23,7 @@
 #ifndef INSTRUMENTPROPERTIESDIALOG_H
 #define INSTRUMENTPROPERTIESDIALOG_H
 
-#include <QDialog>
+#include "tutkadialog.h"
 
 class MIDI;
 class Song;
@@ -32,7 +32,7 @@ namespace Ui {
     class InstrumentPropertiesDialog;
 }
 
-class InstrumentPropertiesDialog : public QDialog
+class InstrumentPropertiesDialog : public TutkaDialog
 {
     Q_OBJECT
 
@@ -47,8 +47,13 @@ public slots:
 
 private slots:
     void updateMidiInterfaceComboBox();
+    void updateArpeggio();
     void setMidiInterface(const QString &name);
     void setMidiChannel(int midiChannel);
+    void toggleArpeggio(bool enabled);
+    void setArpeggioBaseNote(int baseNote);
+    void setArpeggioLength(int length);
+    void advanceTrackerToNextLine();
 
 private:
     MIDI *midi;
