@@ -117,7 +117,6 @@ MainWindow::MainWindow(Player *player, QWidget *parent) :
     connect(player, SIGNAL(positionChanged(unsigned int)), this, SLOT(setPosition(unsigned int)));
     connect(player, SIGNAL(positionChanged(unsigned int)), playingSequenceDialog, SLOT(setPosition(unsigned int)));
     connect(player, SIGNAL(blockChanged(unsigned int)), this, SLOT(setBlock(unsigned int)));
-    connect(player, SIGNAL(blockChanged(unsigned int)), ui->tracker, SLOT(setBlock(unsigned int)));
     connect(player, SIGNAL(blockChanged(unsigned int)), transposeDialog, SLOT(setBlock(unsigned int)));
     connect(player, SIGNAL(blockChanged(unsigned int)), expandShrinkDialog, SLOT(setBlock(unsigned int)));
     connect(player, SIGNAL(blockChanged(unsigned int)), changeInstrumentDialog, SLOT(setBlock(unsigned int)));
@@ -271,7 +270,7 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 {
     bool handled = false;
 
-    if ((event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) && watched->isWindowType() && dynamic_cast<QLineEdit *>(QApplication::focusWidget()) == NULL && dynamic_cast<QSpinBox *>(QApplication::focusWidget()) == NULL && dynamic_cast<Tracker *>(QApplication::focusWidget()) == NULL) {
+    if ((event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) && watched->isWindowType() && dynamic_cast<QLineEdit *>(QApplication::focusWidget()) == NULL && dynamic_cast<QSpinBox *>(QApplication::focusWidget()) == NULL && dynamic_cast<Tracker *>(QApplication::focusWidget()) == NULL && dynamic_cast<QComboBox *>(QApplication::focusWidget()) == NULL) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
 
         if (QApplication::activeWindow() == this || (keyEvent->modifiers() != Qt::NoModifier && keyEvent->key() != Qt::Key_Backtab) || (keyEvent->key() != Qt::Key_Tab && keyEvent->key() != Qt::Key_Backtab && keyEvent->key() != Qt::Key_Left && keyEvent->key() != Qt::Key_Right && keyEvent->key() != Qt::Key_Home && keyEvent->key() != Qt::Key_End && keyEvent->key() != Qt::Key_PageUp && keyEvent->key() != Qt::Key_PageDown)) {
@@ -302,6 +301,11 @@ void MainWindow::mousePressEvent(QMouseEvent *)
     }
 }
 
+void MainWindow::keyPressEvent(QKeyEvent *event)
+{
+    event->accept();
+}
+
 bool MainWindow::keyPress(QKeyEvent *event)
 {
     if (ui->menubar->activeAction() != NULL) {
@@ -633,7 +637,7 @@ void MainWindow::setPosition(unsigned int position)
     ui->labelPosition->setText(tr("Position %1/%2").arg(position + 1).arg(song->playseq(player->playseq())->length()));
 }
 
-void MainWindow::setBlock(unsigned int block)
+void MainWindow::setBlock(unsigned int number)
 {
     if (this->block < song->blocks()) {
         disconnect(song->block(this->block), SIGNAL(nameChanged(QString)), this, SLOT(setBlock()));
@@ -641,17 +645,19 @@ void MainWindow::setBlock(unsigned int block)
         disconnect(song->block(this->block), SIGNAL(tracksChanged(int)), this, SLOT(setDeleteTrackVisibility()));
     }
 
-    this->block = block;
+    this->block = number;
 
-    connect(song->block(block), SIGNAL(nameChanged(QString)), this, SLOT(setBlock()));
-    connect(song->block(block), SIGNAL(commandPagesChanged(int)), this, SLOT(setCommandPage()));
-    connect(song->block(this->block), SIGNAL(tracksChanged(int)), this, SLOT(setDeleteTrackVisibility()));
+    Block *block = song->block(number);
+    connect(block, SIGNAL(nameChanged(QString)), this, SLOT(setBlock()));
+    connect(block, SIGNAL(commandPagesChanged(int)), this, SLOT(setCommandPage()));
+    connect(block, SIGNAL(tracksChanged(int)), this, SLOT(setDeleteTrackVisibility()));
+    ui->tracker->setBlock(block);
 
-    QString name = song->block(block)->name();
+    QString name = block->name();
     if (name.isEmpty()) {
-        ui->labelBlock->setText(tr("Block %1/%2").arg(block + 1).arg(song->blocks()));
+        ui->labelBlock->setText(tr("Block %1/%2").arg(number + 1).arg(song->blocks()));
     } else {
-        ui->labelBlock->setText(tr("Block %1/%2: %3").arg(block + 1).arg(song->blocks()).arg(name));
+        ui->labelBlock->setText(tr("Block %1/%2: %3").arg(number + 1).arg(song->blocks()).arg(name));
     }
     setCommandPage(ui->tracker->commandPage());
     setDeleteTrackVisibility();
@@ -715,7 +721,7 @@ void MainWindow::setSelection(int startTrack, int startLine, int endTrack, int e
 
 void MainWindow::showAbout()
 {
-    QMessageBox::about(this, tr("About Tutka"), tr("Tutka 1.0.5\n\n© 2002-2016 Vesa Halttunen <vesuri@jormas.com>"));
+    QMessageBox::about(this, tr("About Tutka"), tr("Tutka 1.1.0\n\n© 2002-2016 Vesa Halttunen <vesuri@jormas.com>"));
 }
 
 void MainWindow::cutSelection()
