@@ -23,6 +23,7 @@
 #include <cstddef>
 #include <cstdlib>
 #include <sys/time.h>
+#include <QCoreApplication>
 #include <QThread>
 #include <QTimer>
 #include <QFile>
@@ -56,7 +57,8 @@ Player::Player(MIDI *midi, const QString &path, QObject *parent) :
     solo(0),
     postCommand(0),
     postValue(0),
-    tempoChanged(false)
+    tempoChanged(false),
+    killWhenLooped(false)
 {
     connect(midi, SIGNAL(outputsChanged()), this, SLOT(remapMidiOutputs()));
     connect(midi, SIGNAL(startReceived()), this, SLOT(playSong()));
@@ -86,9 +88,11 @@ Player::Player(MIDI *midi, Song *song, QObject *parent) :
     solo(0),
     postCommand(0),
     postValue(0),
-    tempoChanged(false)
+    tempoChanged(false),
+    killWhenLooped(false)
 {
     connect(midi, SIGNAL(outputsChanged()), this, SLOT(remapMidiOutputs()));
+    connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(stop()));
 
     QTimer::singleShot(0, this, SLOT(init()));
 }
@@ -97,6 +101,7 @@ Player::~Player()
 {
     // Stop the player
     stop();
+    wait();
 }
 
 void Player::updateLocation(bool alwaysSendLocationSignals)
@@ -222,7 +227,7 @@ bool Player::nextPosition()
     return looped ? nextSection() : false;
 }
 
-void Player::playNote(unsigned int instrumentNumber, unsigned char note, unsigned char volume, unsigned char track)
+void Player::playNote(unsigned int instrumentNumber, unsigned char note, unsigned char volume, unsigned char track, bool postpone)
 {
     // Notes are played if the track is not muted and no tracks are soloed or the current track is soloed
     if (!song->track(track)->isMuted() && (!solo || (solo && song->track(track)->isSolo()))) {
@@ -240,10 +245,9 @@ void Player::playNote(unsigned int instrumentNumber, unsigned char note, unsigne
             trackStatus->instrument = instrumentNumber;
 
             // Update track status for the selected output
-            trackStatus->note = note + instrument->transpose();
+            trackStatus->volume = instrument->defaultVelocity() * volume / 127 * song->track(track)->volume() / 127 * song->masterVolume() / 127;
             trackStatus->midiChannel = instrument->midiChannel();
             trackStatus->midiInterface = instrument->midiInterface();
-            trackStatus->volume = instrument->defaultVelocity() * volume / 127 * song->track(track)->volume() / 127 * song->masterVolume() / 127;
             trackStatus->hold = instrument->hold() > 0 ? instrument->hold() : -1;
 
             // Make sure the volume isn't too large
@@ -251,8 +255,17 @@ void Player::playNote(unsigned int instrumentNumber, unsigned char note, unsigne
                 trackStatus->volume = 127;
             }
 
-            // Play note
-            midi_->output(instrument->midiInterface())->noteOn(trackStatus->midiChannel, trackStatus->note, trackStatus->volume);
+            if (trackStatus->volume != 0) {
+                // Play note
+                trackStatus->note = note + instrument->transpose();
+                if (postpone) {
+                    postponedNotes.append(NoteOn(instrument->midiInterface(), trackStatus->midiChannel, trackStatus->note, trackStatus->volume));
+                } else {
+                    midi_->output(instrument->midiInterface())->noteOn(trackStatus->midiChannel, trackStatus->note, trackStatus->volume);
+                }
+            } else {
+                trackStatus->note = -1;
+            }
         }
     }
 }
@@ -411,6 +424,7 @@ void Player::handleCommand(QSharedPointer<TrackStatus> trackStatus, unsigned cha
                         } else {
                             output->noteOff(midiChannel, trackStatus->note, 127);
                             trackStatus->note = -1;
+                            trackStatus->line = -1;
                         }
                     }
                 } else {
@@ -549,36 +563,38 @@ void Player::run()
             line_ %= block->length();
         }
 
-        // Stop notes if there are new notes about to be played
         for (int track = 0; track < block->tracks(); track++) {
             QSharedPointer<TrackStatus> trackStatus = trackStatuses[track];
 
             // The track is taken into account if the track is not muted and no tracks are soloed or the current track is soloed
             if (!song->track(track)->isMuted() && (!solo || (solo && song->track(track)->isSolo()))) {
-                int delay = 0;
+                unsigned int volume = 127;
+                int delay = 0, hold = -1;
                 unsigned char basenote = block->note(line_, track);
                 unsigned char instrument = block->instrument(line_, track);
                 unsigned char note = basenote;
+                Block *arpeggio = NULL;
 
                 if (note != 0) {
-                    // Use previous instrument if none defined
-                    int arpeggioInstrument = instrument > 0 ? (instrument - 1) : trackStatus->instrument;
-                    trackStatus->line = 0;
-                    if (song->instrument(arpeggioInstrument)->arpeggio() != NULL) {
-                        // Add arpeggio note to the track's base note
-                        Block *arpeggio = song->instrument(arpeggioInstrument)->arpeggio();
-                        note = basenote + ((char)arpeggio->note(trackStatus->line, 0) - (char)song->instrument(arpeggioInstrument)->basenote());
+                    // Start the arpeggio from the beginning if a note is played on the track
+                    if (tick == 0) {
+                        trackStatus->line = 0;
                     }
                 } else {
-                    // Play arpeggio of previous instrument if any
-                    int arpeggioinstrument = trackStatus->instrument;
-                    if (arpeggioinstrument >= 0 && song->instrument(arpeggioinstrument)->arpeggio() != NULL) {
-                        // Add arpeggio note to the track's base note
-                        Block *arpeggio = song->instrument(arpeggioinstrument)->arpeggio();
-                        note = trackStatus->baseNote + ((char)arpeggio->note(trackStatus->line, 0) - (char)song->instrument(arpeggioinstrument)->basenote());
+                    basenote = trackStatus->baseNote;
+                }
+
+                int arpeggioInstrument = note != 0 && instrument > 0 ? (instrument - 1) : trackStatus->instrument;
+                if (arpeggioInstrument >= 0 && trackStatus->line >= 0) {
+                    // Add arpeggio note (if any) to the track's base note
+                    arpeggio = song->instrument(arpeggioInstrument)->arpeggio();
+                    if (arpeggio != NULL) {
+                        unsigned char arpeggioNote = arpeggio->note(trackStatus->line, 0);
+                        note = arpeggioNote != 0 ? (basenote + ((char)arpeggioNote - (char)song->instrument(arpeggioInstrument)->arpeggioBaseNote())) : 0;
                     }
                 }
 
+                // Stop notes if there are new notes about to be played
                 if (note != 0) {
                     for (int commandPage = 0; commandPage < commandPages; commandPage++) {
                         unsigned char command = block->command(line_, track, commandPage);
@@ -613,40 +629,6 @@ void Player::run()
                         }
                     }
                 }
-            }
-        }
-
-        // Play notes scheduled to be played
-        for (int track = 0; track < block->tracks(); track++) {
-            QSharedPointer<TrackStatus> trackStatus = trackStatuses[track];
-
-            // The track is taken into account if the track is not muted and no tracks are soloed or the current track is soloed
-            if (!song->track(track)->isMuted() && (!solo || (solo && song->track(track)->isSolo()))) {
-                unsigned int volume = 127;
-                int delay = 0, hold = -1;
-                unsigned char basenote = block->note(line_, track);
-                unsigned char instrument = block->instrument(line_, track);
-                unsigned char note = basenote;
-                Block *arpeggio = NULL;
-
-                if (note != 0) {
-                    // Use previous instrument if none defined
-                    int arpeggioinstrument = instrument > 0 ? (instrument - 1) : trackStatus->instrument;
-                    trackStatus->line = 0;
-                    if (song->instrument(arpeggioinstrument)->arpeggio() != NULL) {
-                        // Add arpeggio note to the track's base note
-                        arpeggio = song->instrument(arpeggioinstrument)->arpeggio();
-                        note = basenote + ((char)arpeggio->note(trackStatus->line, 0) - (char)song->instrument(arpeggioinstrument)->basenote());
-                    }
-                } else {
-                    // Play arpeggio of previous instrument if any
-                    int arpeggioinstrument = trackStatus->instrument;
-                    if (arpeggioinstrument >= 0 && song->instrument(arpeggioinstrument)->arpeggio() != NULL) {
-                        // Add arpeggio note to the track's base note
-                        arpeggio = song->instrument(arpeggioinstrument)->arpeggio();
-                        note = trackStatus->baseNote + ((char)arpeggio->note(trackStatus->line, 0) - (char)song->instrument(arpeggioinstrument)->basenote());
-                    }
-                }
 
                 if (arpeggio != NULL) {
                     // Handle commands on all arpeggio command pages
@@ -657,6 +639,7 @@ void Player::run()
                     }
                 }
 
+                bool hadVolume = volume > 0;
                 // Handle commands on all command pages
                 for (int commandPage = 0; commandPage < commandPages; commandPage++) {
                     unsigned char command = block->command(line_, track, commandPage);
@@ -685,7 +668,7 @@ void Player::run()
 
                     // Play note if instrument is defined
                     if (instrument != 0) {
-                        playNote(instrument - 1, note, volume, track);
+                        playNote(instrument - 1, note, volume, track, true);
 
                         if (instrument <= song->instruments()) {
                             instr = song->instrument(instrument - 1);
@@ -699,6 +682,11 @@ void Player::run()
                         }
 
                         trackStatus->hold = hold == 0 ? -1 : hold;
+
+                        // If there would have been volume but the block's commands killed it, stop the arpeggio
+                        if (hadVolume && volume == 0) {
+                            trackStatus->line = -1;
+                        }
                     }
                 }
 
@@ -711,6 +699,13 @@ void Player::run()
             }
         }
 
+        // Play notes scheduled to be played
+        for (int i = 0; i < postponedNotes.count(); i++) {
+            const NoteOn &noteOn = postponedNotes.at(i);
+            midi_->output(noteOn.midiInterface)->noteOn(noteOn.midiChannel, noteOn.note, noteOn.volume);
+        }
+        postponedNotes.clear();
+
         // Decrement hold times of notes and stop notes that should be stopped
         for (int track = 0; track < song->maxTracks(); track++) {
             QSharedPointer<TrackStatus> trackStatus = trackStatuses[track];
@@ -739,7 +734,7 @@ void Player::run()
                 QSharedPointer<TrackStatus> trackStatus = trackStatuses[track];
                 int arpeggioInstrument = trackStatus->instrument;
 
-                if (arpeggioInstrument >= 0 && trackStatus->baseNote >= 0) {
+                if (arpeggioInstrument >= 0 && trackStatus->baseNote >= 0 && trackStatus->line >= 0) {
                     Instrument *instrument = song->instrument(arpeggioInstrument);
                     if (instrument->arpeggio() != NULL) {
                         trackStatus->line++;
@@ -789,7 +784,7 @@ void Player::run()
         }
 
         // Check whether this thread should be killed
-        if (killThread || (scheduler == NULL && looped)) {
+        if (killThread || (killWhenLooped && looped)) {
             break;
         }
         song->unlock();
@@ -849,6 +844,7 @@ void Player::playWithoutScheduling()
 {
     scheduler = NULL;
     mode_ = ModePlaySong;
+    killWhenLooped = true;
     for (int instrument = 0; instrument < song->instruments(); instrument++) {
         song->instrument(instrument)->setMidiInterface(0);
     }
@@ -892,6 +888,15 @@ void Player::play(Mode mode, bool cont)
     // Get the starting time
     resetTime(!cont);
 
+    // Send MIDI start or continue if sync is requested
+    if (mode != ModeIdle && song->sendSync()) {
+        if (cont) {
+            midi()->cont();
+        } else {
+            midi()->start();
+        }
+    }
+
     // For some reason the priority setting crashes with realtime Jack
     //            if (editor == NULL || editor_player_get_external_sync(editor) != EXTERNAL_SYNC_JACK_START_ONLY)
     start(syncMode == Off ? QThread::TimeCriticalPriority : QThread::NormalPriority);
@@ -919,6 +924,11 @@ void Player::stop()
             externalSync(0);
         }
 
+        // Send MIDI stop if sync is requested
+        if (song->sendSync()) {
+            midi()->stop();
+        }
+
         // Wait until the thread is dead
         wait();
         killThread = false;
@@ -1013,9 +1023,7 @@ void Player::init()
     for (int message = 0; message < song->messages(); message++) {
         if (song->message(message)->isAutoSend()) {
             for (int output = 0; output < midi_->outputs(); output++) {
-                if (midi_->output(output)->isEnabled()) {
-                    midi_->output(output)->writeRaw(song->message(message)->data());
-                }
+                midi_->output(output)->writeRaw(song->message(message)->data());
             }
         }
     }
@@ -1242,6 +1250,11 @@ void Player::setScheduler(Scheduler *scheduler)
     this->scheduler = scheduler;
 }
 
+void Player::setKillWhenLooped(bool killWhenLooped)
+{
+    this->killWhenLooped = killWhenLooped;
+}
+
 unsigned int Player::section() const
 {
     return section_;
@@ -1285,6 +1298,7 @@ Player::TrackStatus::TrackStatus()
 void Player::TrackStatus::reset()
 {
     instrument = -1;
+    line = -1;
     previousCommand = 0;
     note = -1;
     midiChannel = -1;
