@@ -52,11 +52,20 @@ class Player : public QThread {
         char midiChannel;
         char volume;
         char note;
-        char hold;
+        int hold;
 
         friend class Player;
     };
 
+    class NoteOn {
+    public:
+        NoteOn(unsigned int midiInterface, char midiChannel, char note, char volume) { this->midiInterface = midiInterface; this->midiChannel = midiChannel; this->note = note; this->volume = volume; }
+        unsigned int midiInterface;
+        char midiChannel;
+        char note;
+        char volume;
+    };
+
 public:
     enum Command {
         CommandPreviousCommandValue = 0x00,
@@ -105,7 +114,7 @@ public:
     void playWithoutScheduling();
 
     // Plays a note using given instrument on a given channel
-    void playNote(unsigned int, unsigned char, unsigned char, unsigned char);
+    void playNote(unsigned int instrumentNumber, unsigned char note, unsigned char volume, unsigned char track, bool postpone = false);
     // Stops notes playing on muted tracks
     void stopMuted();
     // Stops notes playing at the moment
@@ -127,6 +136,9 @@ public:
     void setExternalSync(ExternalSync externalSync);
     void setScheduler(Scheduler *scheduler);
 
+    // Set whether the player should quit when the song loops
+    void setKillWhenLooped(bool killWhenLooped);
+
     MIDI *midi() const;
 
 public slots:
@@ -245,6 +257,10 @@ private:
     unsigned char postCommand, postValue;
     // Indicates whether the tempo has changed
     bool tempoChanged;
+    // A list of notes to be played
+    QList<NoteOn> postponedNotes;
+    // Whether the player should quit when the song loops
+    bool killWhenLooped;
 };
 
 #endif // PLAYER_H_
