@@ -71,7 +71,8 @@ Tracker::Tracker(QWidget *parent) :
     instrument_(0),
     octave_(3),
     inEditMode(false),
-    inChordMode(false)
+    inChordMode(false),
+    translucentWhenNotFocused(false)
 {
     font.setStyleHint(QFont::TypeWriter);
     font.setStyleStrategy(QFont::ForceIntegerMetrics);
@@ -195,10 +196,8 @@ void Tracker::setSong(Song *song)
     }
 }
 
-void Tracker::setBlock(unsigned int number)
+void Tracker::setBlock(Block *block)
 {
-    Block *block = song_ != NULL ? song_->block(number) : NULL;
-
     if (block_ != block) {
         if (block_ != NULL) {
             disconnect(block_, SIGNAL(areaChanged(int,int,int,int)), this, SLOT(redrawArea(int,int,int,int)));
@@ -589,6 +588,7 @@ void Tracker::drawClever(const QRect &area)
     }
 
     QPainter painter(this);
+    painter.setOpacity(hasFocus() ? 1.0 : (translucentWhenNotFocused ? 0.5 : 1.0));
     if (block_ != NULL) {
         // If selection has been added or removed, redraw everything
         if (selectionStartTrack != oldSelectionStartTrack) {
@@ -639,7 +639,6 @@ void Tracker::drawClever(const QRect &area)
     } else {
         painter.fillRect(area.x(), area.y(), area.width(), area.height(), isEnabled() ? backgroundBrush : QPalette().shadow());
     }
-
 }
 
 void Tracker::drawStupid(const QRect &area)
@@ -1270,3 +1269,10 @@ void Tracker::removeChordNote()
         emit lineEdited();
     }
 }
+
+void Tracker::setTranslucentWhenNotFocused(bool translucentWhenNotFocused)
+{
+    this->translucentWhenNotFocused = translucentWhenNotFocused;
+
+    update();
+}
