@@ -61,12 +61,13 @@ public:
     void setSelection(int startTrack, int startLine, int endTrack, int endLine);
     void addChordNote();
     void removeChordNote();
+    void setTranslucentWhenNotFocused(bool translucentWhenNotFocused);
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void keyReleaseEvent(QKeyEvent *event);
 
 public slots:
     void setSong(Song *song);
-    void setBlock(unsigned int block);
+    void setBlock(Block *block);
     void setLine(int line);
     void setLeftmostTrack(int leftmostTrack);
     void setEditMode(bool enabled);
@@ -178,6 +179,8 @@ private:
 
     bool inEditMode;
     bool inChordMode;
+
+    bool translucentWhenNotFocused;
 };
 
 #endif // TRACKER_H
